Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/arch/sparc/include Add a CPU_ISSUN4D predicate.



details:   https://anonhg.NetBSD.org/src/rev/c00f16bfdd78
branches:  trunk
changeset: 534115:c00f16bfdd78
user:      thorpej <thorpej%NetBSD.org@localhost>
date:      Wed Jul 17 06:07:29 2002 +0000

description:
Add a CPU_ISSUN4D predicate.

diffstat:

 sys/arch/sparc/include/param.h |  16 ++++++++++++----
 1 files changed, 12 insertions(+), 4 deletions(-)

diffs (44 lines):

diff -r 0e76b88d49aa -r c00f16bfdd78 sys/arch/sparc/include/param.h
--- a/sys/arch/sparc/include/param.h    Wed Jul 17 05:57:47 2002 +0000
+++ b/sys/arch/sparc/include/param.h    Wed Jul 17 06:07:29 2002 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: param.h,v 1.54 2002/07/17 05:57:47 thorpej Exp $ */
+/*     $NetBSD: param.h,v 1.55 2002/07/17 06:07:29 thorpej Exp $ */
 
 /*
  * Copyright (c) 1992, 1993
@@ -189,8 +189,8 @@
  * system.  So insist on SUN4M defined and SUN4 and SUN4C not defined.
  */
 #if defined(MSIIEP)
 #if defined(SUN4) || defined(SUN4C)
 #error "microSPARC-IIep kernels cannot support sun4 or sun4c"
 #endif
 #if !defined(SUN4M)
 #error "microSPARC-IIep kernel must have 'options SUN4M'"
@@ -207,7 +207,7 @@
  * kernel.
  */
 #define        CPU_NTYPES      (defined(SUN4) + defined(SUN4C) + \
-                        defined(SUN4M))
+                        defined(SUN4M) + defined(SUN4D))
 
 /*
  * Step 2: Define the CPU type predicates.  Rules:
@@ -244,6 +244,14 @@
 #      define CPU_ISSUN4M      (cputyp == CPU_SUN4M)
 #endif
 
+#if !defined(SUN4D)
+#      define CPU_ISSUN4D      (0)
+#elif CPU_NTYPES == 1
+#      define CPU_ISSUN4D      (1)
+#else
+#      define CPU_ISSUN4D      (cputyp == CPU_SUN4D)
+#endif
+
 #define        CPU_ISSUN4U             (0)
 
 /*
@@ -189,8 +189,8 @@
  */
 #if defined(MSIIEP)
-#if defined(SUN4) || defined(SUN4C)
-#error "microSPARC-IIep kernels cannot support sun4 or sun4c"
+#if defined(SUN4) || defined(SUN4C) || defined(SUN4D)
+#error "microSPARC-IIep kernels cannot support sun4, sun4c, or sun4d"
 #endif
 #if !defined(SUN4M)



Home | Main Index | Thread Index | Old Index